@@ -2,11 +2,13 @@
 from __future__ import absolute_import
 
 import functools
+import json
 import logging
 import os
 import urllib2
 from cStringIO import StringIO
 from csv import writer as CSVWriter
+from datetime import datetime
 
 from tornado import web as tornadoweb
 from tornado.concurrent import run_on_executor
@@ -30,6 +32,7 @@ from .temboardclient import (
     TemboardError,
     temboard_request,
 )
+from .toolkit.pycompat import PY2
 
 
 logger = logging.getLogger(__name__)
@@ -230,6 +233,8 @@ class ErrorHelper(object):
             except HTTPError as e:
                 code = e.status_code
                 message = e.log_message
+                if code == 404:
+                    message += " Plugin may not be activated on agent side"
             except Exception as e:
                 # Show traceback for developer, and HTML page for user.
                 logger.exception("Unhandled Error:")
@@ -278,7 +283,7 @@ class InstanceHelper(object):
         Ensure that the plugin is active for given instance
         '''
         if name not in [p.plugin_name for p in self.instance.plugins]:
-            raise HTTPError(408, "Plugin not activated.")
+            raise HTTPError(408, "Plugin %s not activated." % name)
 
     def fetch_instance(self, address, port):
         self.instance = get_instance(self.request.db_session, address, port)
@@ -579,6 +584,23 @@ def make_error(request, code, message):
     return response
 
 
+class JSONEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, datetime):
+            return obj.isoformat()
+        else:
+            return super(JSONEncoder, self).default(obj)
+
+
+# Change default cls argument to custom encoder.
+if PY2:
+    defaults = list(json.dumps.func_defaults)
+    defaults[4] = JSONEncoder
+    json.dumps.func_defaults = tuple(defaults)
+else:
+    json.dumps.__kwdefaults__['cls'] = JSONEncoder
+
+
 # Global app instance for registration of core handlers.
 app = WebApplication()
 # Hijack tornado.web access_log to log request in temboardui namespace.
